from django.db import models
from django.utils.translation import gettext_lazy as _

from djangoldp_tems.models.__base_named_model import baseTEMSNamedModel
from djangoldp_tems_trial1.models.category import Trial1Category
from djangoldp_tems_trial1.models.format import Trial1Format
from djangoldp_tems_trial1.models.object import Trial1Object


class Trial1Asset(baseTEMSNamedModel):
    size = models.PositiveBigIntegerField(blank=True, null=True, default=0)
    format = models.ForeignKey(Trial1Format, blank=True, null=True, on_delete=models.SET_NULL)
    category = models.ForeignKey(Trial1Category, blank=True, null=True, on_delete=models.SET_NULL)
    object = models.ForeignKey(
        Trial1Object,
        on_delete=models.CASCADE,
        related_name="assets",
        blank=True,
        null=True,
    )

    def __str__(self):
        return self.name or self.urlid

    class Meta(baseTEMSNamedModel.Meta):
        container_path = "/objects/assets/trial1/"
        verbose_name = _("TEMS Asset")
        verbose_name_plural = _("TEMS Assets")

        serializer_fields = [
            "@id",
            "creation_date",
            "update_date",
            "name",
            "size",
            "format",
            "category",
        ]
        nested_fields = [
            "format",
            "category",
        ]
        rdf_type = "tems:Asset"
